#[non_exhaustive]pub enum SecretError {
Backend(String),
Unavailable,
}Expand description
Errors that can occur while interacting with a
SecretStore.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Backend(String)
The underlying OS keyring or fallback backend rejected the operation.
Backend implementors MUST NOT include the secret value, the keyring service/account names containing user paths, or any data that could disclose the secret in this string.
The platform does not provide secure storage and no fallback was configured by the caller.