pub struct Project { /* private fields */ }Expand description
A project that has variables linked to it via an evault.toml manifest.
Project records the location of the manifest and a human-friendly name.
Linkage details live in ProjectVar records.
Examples
use evault_core::model::Project;
use std::path::PathBuf;
let p = Project::new("my-app", PathBuf::from("./my-app"));
assert_eq!(p.name(), "my-app");Implementations
Sourceimpl Project
impl Project
Sourcepub fn new(name: impl Into<String>, path: PathBuf) -> Self
pub fn new(name: impl Into<String>, path: PathBuf) -> Self
Create a new Project with a fresh identifier.
path is the directory that contains (or will contain) the
evault.toml manifest.