ProcessOutcome

Struct ProcessOutcome 

pub struct ProcessOutcome {
    pub exit_code: Option<i32>,
}
Result of running a child process.

Fields

exit_code: Option<i32>

Exit status reported by the OS. None if the process was terminated by a signal (Unix).

Implementations

Source

impl ProcessOutcome

pub const fn is_success(&self) -> bool

Returns true when the process exited normally with code 0.