#[non_exhaustive]pub enum MaterializerError {
Io(Error),
MissingVar(String),
Backend(String),
}Expand description
Errors that can occur while materializing a .env file from a manifest.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(Error)
I/O error while reading or writing files.
MissingVar(String)
The manifest referenced a variable that is missing from the registry.
Backend(String)
The materializer backend reported an unexpected failure.
Backend implementors MUST NOT include the rendered values, the secret material, or absolute path components in this string.